%% Load the data from the comma delimited text file 'NZ20110222earthquakes.csv' with 
%% the following column IDs 
%% CUSP_ID,LAT,LONG,NZMGE,NZMGN,ORI_YEAR,ORI_MONTH,ORI_DAY,ORI_HOUR,ORI_MINUTE,ORI_SECOND,MAG,DEPTH 
%% Using MATLAB?s dlmread command we can assign the data as a matrix to EQ; 
%% note that the option 1,0 to dlmread skips first row of column descriptors 
% 
% the variable EQall is about to be assigned the data as a matrix 
EQall = dlmread('NZ20110222earthquakes.csv', ',' , 1, 0); 
size(EQall) % report the dimensions or size of the matrix EQall 
%ans = 145 14 

EQall(any(isnan(EQall),2),:) = []; %Remove any rows containing NaNs from the matrix EQall 
% report the size of EQall and see if it is different from before we removed and NaN containing rows 
size(EQall) 
% output: ans = 145 14 
% remove locations outside Chch and assign it to a new variable called EQ 
% only keep earthquake hypocenter locations inside Chch
% only keep earthquakes with magnitude >3 
EQ = EQall(-43.75<EQall(:,2) & EQall(:,2)<-43.45 & 172.45<EQall(:,3) ...
                             & EQall(:,3)<172.9 & EQall(:,12)>3, :);  
% now report the size of the earthquakes in Christchurch in variable EQ 
size(EQ) 
% output: ans = 124 14 

% assign the four variables of interest
LatData=EQ(:,2); LonData=EQ(:,3); MagData=EQ(:,12); DepData=EQ(:,13);

% finally make a plot matrix of these 124 4-tuples as red points 
plotmatrix([LatData,LonData,MagData,DepData], 'r.'); 

% % top 5 magnitude EQs
% [Msorted I] = sort(MagData,'descend');
% Top5Is = I(1:5);
% TopEQs = EQ(Top5Is, [9,10,11,2,3,12,13])

% % 10 earthquakes around the main one on 2-22-11
i=30; Shocks11=EQ(i:i+10,[9,10,11,2,3,12,13])
% occurrence time in minutes since 1:00PM
ts11=[Shocks11(1:6,2)' Shocks11(7:11,2)'+60]
figure
ECDF(ts11,1.5,0,20); 
xlabel('$t$ (in minutes since 1:00 PM on 22-02-2011)','interpreter','latex','FontSize',16); 
xlim([0,120]); % limits of the x-axis on plot
ylabel('$\widehat{F}_{11}(t)$','interpreter','latex','FontSize',16);
% the following gives a full 5x5 matrix of scatter plots
% minutes since 1:00PM on 22-02-2011,LAT,LON,MAG,DEPTH
plotmatrix([ts11' Shocks11(:,4:7)], 'ko');