% Hi Omar (and others in EMTH210 who may be interested in why Z_1+Z_2 is 
% not 2*Z_1 in distribution),
% 
% Let me try to explain why Z_1 + Z_2 is not 2*Z_1 in distribution when 
% Z_1 and Z_2 are independent Normal(0,1) RVs.
% 
% Quickly, think of the following samples of size two each from 
% Z_1 and Z_2:
% z_1 = (z_1,1, z_1,2) = (0.03, -0.01)
% z_2 = (z_2,1, z_2,2) = (-0.02, 0.1)
% 
% Then, when you multiply Z_1 by 2 the samples in z_1 become 
% (2*0.03, 2*(-0.01)) = (0.06, - 0.02).
% Whereas, the samples from z_1 and z_2 when added become 
% (0.03+-0.02, -0.01+0.1) = (0.01, 0.09 ).
% 
% So, in effect multiplying by 2 stretches each sample in z_1 by 2 away 
% from the origin and thus widens the distribution 
% (increases variance of 2*Z_1 when compared to variance of 1 for Z_1 ).
% 
% Whereas, Z_1+Z_2, on the other hand, adds samples independently drawn 
% from Z_1 and Z_2, the two distinct Normal(0,1) RVs.  
% In this case, about half of these additions will result in positive 
% numbers being added to negative numbers and thus the sum will be closer 
% to 0 on average.  Thus the variance of Z_1+Z_2 will be smaller than the 
% variance for 2*Z_1 but larger than 1, the variance of Z_1 or the 
% Variance of Z_2 alone.
% 
% Here is a quick simulation to drive the point home:

z1=randn(1,10) % produce 10 samples from Z_1 ~ Normal(0,1) RV
z2=randn(1,10) % produce 10 samples from Z_2 ~ Normal(0,1) RV
2*z1 % multiply each of the 10 samples in z_1 by 2 to transform them into samples from 2*Z_1
var(2*z1) % the sample variance for 2*z_1
z1+z2 % add z1 to z2 component-wise to transform them into samples from Z_1+Z_2
var(z1+z2) % the sample variance for z_1+z2
var(z1) % just the sample variance for z1
var(z2) % just the sample variance for z2



% Note that the above calls to 'var' function in MATLAB are for the sample 
% variances and not the population variance which is V(Z_1)=V(Z_2)=1 or 
% the V(2*Z_1) and V(Z_1+Z_2) that you can get from their CFs analytically.
% 
% However, we can use repeat above simulation with much larger samples, say 
% of size n=10,000 for example, and notice that the sample variances are 
% approaching the populaiton variances:

z1=randn(1,10000); % produce 10000 samples from Z_1 ~ Normal(0,1) RV
z2=randn(1,10000); % produce 10000 samples from Z_2 ~ Normal(0,1) RV
2*z1; % multiply each of the 10 samples in z_1 by 2 to transform them into samples from 2*Z_1
var(2*z1) % the sample variance for 2*z_1
z1+z2; % add z1 to z2 component-wise to transform them into samples from Z_1+Z_2
var(z1+z2) % the sample variance for z_1+z2
var(z1) % just the sample variance for z1
var(z2) % just the sample variance for z2

% just plot these samples as frequency histograms on the same scale
% of [-10,10] and notice the location and spread of the distributions
subplot(2,2,1)
hist(z1,50)
xlabel('z_1'); ylabel('frequency'); title('Z_1')
xlim([-10,10])

subplot(2,2,2)
hist(z2,50)
xlabel('z_2'); ylabel('frequency'); title('Z_2')
xlim([-10,10])

subplot(2,2,3)
hist(2*z1,50)
xlabel('2 z_1'); ylabel('frequency'); title('2 Z_1')
xlim([-10,10])

subplot(2,2,4)
hist(z1+z2,50)
xlabel('z_1+z_2'); ylabel('frequency'); title('Z_1 + Z_2')
xlim([-10,10])


